/**
 * Introduction
 *
 * @title ROV - Easy applications from C
 *
 * @copyright Jason Tribbeck / 7th ARM 1994-2001
 *
 * @authors Jason Tribbeck
 *
 * @file fileinfo.c
 */

#include <stdio.h>
#include <stdarg.h>
#include <string.h>

#include "kernel.h"

#ifndef __GNUC__
#pragma -s1
#endif

#include "main.h"
#include "canvas.h"
#include "icons.h"
#include "file.h"
#include "msg.h"
#include "draw.h"

static char _modstr[8], _typestr[16], _namestr[256], _sizestr[32], _datestr[64], _spritestr[16];
static icon _i[10];

canvas fileinfo_create(void)
{
  canvas c;

  c = canvas_create(500 + 64, 308, msg_lookup("AbFile:About this file"));
  if(!c) return 0;
  canvas_setflags(c, 0x7f000000U, CANVAS_TITLEBAR);
  canvas_make(c);

  strcpy(_spritestr, "file_fff");
  _i[0] = icon_createsprite(c, 32, 210, SPRITE_WIMP, _spritestr);
  _i[1] = icon_createrjtext(c, 120, 8, msg_lookup("Date:Date"));
  _i[2] = icon_createfixedinfofield(c, 128, 8, _datestr, 300 + 64 + 64);
  _i[3] = icon_createrjtext(c, 120, 68, msg_lookup("Size:Size"));
  _i[4] = icon_createfixedinfofield(c, 128, 68, _sizestr, 300 + 64 + 64);
  _i[5] = icon_createfixedinfofield(c, 8, 128, _namestr, 420 + 64 + 64);
  icon_setjustification(_i[5], ICON_RIGHTJUSTIFIED);
  _i[6] = icon_createrjtext(c, 300, 188, msg_lookup("Type:Type"));
  _i[7] = icon_createfixedinfofield(c, 308, 188, _typestr, 120 + 64 + 64);
  _i[8] = icon_createrjtext(c, 300, 248, msg_lookup("Mod:Modified?"));
  _i[9] = icon_createfixedinfofield(c, 308, 248, _modstr, 120 + 64 + 64);

  return c;
}

void fileinfo_setup(char * name, int type, int length, date_str * date, BOOL modified)
{
  int i;

  if(!modified) main_strcpy(_modstr, msg_lookup("No:No")); else main_strcpy(_modstr, msg_lookup("Yes:Yes"));
  strncpy(_sizestr, file_sizetostr(length), 32);
  strncpy(_namestr, name, 256);
  if((type < 0x1000) && (type >= 0)) {
    sprintf(_typestr, "%s (%-.3x)", file_typetostr(type), type);
    sprintf(_spritestr, "file_%-.3x", type);
    if(!sprite_spriteexists(SPRITE_WIMP, _spritestr)) {
      strcpy(_spritestr, "file_xxx");
    }
  } else {
    switch(type) {
    case 0x1000 :
      strcpy(_typestr, msg_lookup("Dir:Directory"));
      strcpy(_spritestr, "directory");
      strncpy(_sizestr, msg_lookup("Unsized:Unsized"), 32);
      break;
    case 0x2000 :
      strcpy(_typestr, msg_lookup("App:Application"));
      strcpy(_spritestr, "application");
      strncpy(_sizestr, msg_lookup("Unsized:Unsized"), 32);
      break;
    case -1 :
      strcpy(_typestr, msg_lookup("Untyped:Untyped"));
      strcpy(_spritestr, "file_xxx");
      break;
    }
  }
  if(type != -1) {
    strncpy(_datestr, file_datetostr(date), 64);
  } else {
    strncpy(_datestr, msg_lookup("Undated:Undated"), 64);
  }
  for(i = 0; i < 10; i ++) icon_update(_i[i]);
}
